@@ -8,40 +8,12 @@
 // Media Patent License 1.0 was not distributed with this source code in the
 // PATENTS file, you can obtain it at www.aomedia.org/license/patent.
 
-#![deny(bare_trait_objects)]
-#![allow(clippy::cast_lossless)]
-#![allow(clippy::cast_ptr_alignment)]
-#![allow(clippy::cognitive_complexity)]
-#![allow(clippy::needless_range_loop)]
-#![allow(clippy::too_many_arguments)]
-#![allow(clippy::verbose_bit_mask)]
-#![allow(clippy::unreadable_literal)]
-#![allow(clippy::many_single_char_names)]
-// Performance lints
-#![warn(clippy::linkedlist)]
-#![warn(clippy::missing_const_for_fn)]
-#![warn(clippy::mutex_integer)]
-#![warn(clippy::suboptimal_flops)]
-// Correctness lints
-#![warn(clippy::expl_impl_clone_on_copy)]
-#![warn(clippy::mem_forget)]
-#![warn(clippy::path_buf_push_overwrite)]
-// Clarity/formatting lints
-#![warn(clippy::map_flatten)]
-#![warn(clippy::mut_mut)]
-#![warn(clippy::needless_borrow)]
-#![warn(clippy::needless_continue)]
-#![warn(clippy::range_plus_one)]
-// Documentation lints
-#![warn(clippy::doc_markdown)]
-#![warn(clippy::missing_errors_doc)]
-#![warn(clippy::missing_panics_doc)]
+//! Simple ivf muxer
 
-/// Simple ivf muxer
-///
-use bitstream_io::{BitRead, BitReader, BitWrite, BitWriter, LittleEndian};
 use std::io;
 
+use bitstream_io::{BitRead, BitReader, BitWrite, BitWriter, LittleEndian};
+
 /// # Panics
 ///
 /// - If header cannot be written to output file.
@@ -51,15 +23,15 @@ pub fn write_ivf_header(
 ) {
   let mut bw = BitWriter::endian(output_file, LittleEndian);
   bw.write_bytes(b"DKIF").unwrap();
-  bw.write(16, 0).unwrap(); // version
-  bw.write(16, 32).unwrap(); // version
+  bw.write::<16, _>(0).unwrap(); // version
+  bw.write::<16, _>(32).unwrap(); // version
   bw.write_bytes(b"AV01").unwrap();
-  bw.write(16, width as u16).unwrap();
-  bw.write(16, height as u16).unwrap();
-  bw.write(32, framerate_num as u32).unwrap();
-  bw.write(32, framerate_den as u32).unwrap();
-  bw.write(32, 0).unwrap();
-  bw.write(32, 0).unwrap();
+  bw.write::<16, _>(width as u16).unwrap();
+  bw.write::<16, _>(height as u16).unwrap();
+  bw.write::<32, _>(framerate_num as u32).unwrap();
+  bw.write::<32, _>(framerate_den as u32).unwrap();
+  bw.write::<32, _>(0).unwrap();
+  bw.write::<32, _>(0).unwrap();
 }
 
 /// # Panics
@@ -69,8 +41,8 @@ pub fn write_ivf_frame(
   output_file: &mut dyn io::Write, pts: u64, data: &[u8],
 ) {
   let mut bw = BitWriter::endian(output_file, LittleEndian);
-  bw.write(32, data.len() as u32).unwrap();
-  bw.write(64, pts).unwrap();
+  bw.write::<32, _>(data.len() as u32).unwrap();
+  bw.write::<64, _>(pts).unwrap();
   bw.write_bytes(data).unwrap();
 }
 
@@ -99,18 +71,18 @@ pub fn read_header(r: &mut dyn io::Read) -> io::Result<Header> {
     return Err(io::ErrorKind::InvalidData.into());
   }
 
-  let _v0: u16 = br.read(16)?;
-  let _v1: u16 = br.read(16)?;
+  let _v0: u16 = br.read::<16, _>()?;
+  let _v1: u16 = br.read::<16, _>()?;
   br.read_bytes(&mut tag)?;
 
-  let w: u16 = br.read(16)?;
-  let h: u16 = br.read(16)?;
+  let w: u16 = br.read::<16, _>()?;
+  let h: u16 = br.read::<16, _>()?;
 
-  let timebase_den: u32 = br.read(32)?;
-  let timebase_num: u32 = br.read(32)?;
+  let timebase_den: u32 = br.read::<32, _>()?;
+  let timebase_num: u32 = br.read::<32, _>()?;
 
-  let _: u32 = br.read(32)?;
-  let _: u32 = br.read(32)?;
+  let _: u32 = br.read::<32, _>()?;
+  let _: u32 = br.read::<32, _>()?;
 
   Ok(Header { tag, w, h, timebase_num, timebase_den })
 }
@@ -126,8 +98,8 @@ pub struct Packet {
 pub fn read_packet(r: &mut dyn io::Read) -> io::Result<Packet> {
   let mut br = BitReader::endian(r, LittleEndian);
 
-  let len: u32 = br.read(32)?;
-  let pts: u64 = br.read(64)?;
+  let len: u32 = br.read::<32, _>()?;
+  let pts: u64 = br.read::<64, _>()?;
   let mut buf = vec![0u8; len as usize];
 
   br.read_bytes(&mut buf)?;
@@ -137,9 +109,10 @@ pub fn read_packet(r: &mut dyn io::Read) -> io::Result<Packet> {
 
 #[cfg(test)]
 mod tests {
-  use crate::{read_header, read_packet};
   use std::io::{BufReader, ErrorKind::InvalidData};
 
+  use crate::{read_header, read_packet};
+
   #[test]
   fn read_invalid_headers() {
     // Invalid magic.
